import config_lang_serder

a = config_lang_serder.read("../test.toml")
config_lang_serder.write(a, "../test_created.json")

# fail = config_lang_serder.read("../test.html")  # will throw unsupported file extension
pass



from typing import Dict

def read(path: str) -> Dict:
    """
    A General method to read a file and return its contents as a Python dict based on the file extension.
    :param path: the path to the file
    :return: a python dict
    """

def write(dict: Dict, path: str) -> None:
    """
    A General method to write a Python dict to a file based on the file extension
    :param dict: a python dict
    :param path: the path to the file
    :return: None
    """
